Examples
--------

See the `CircuitPython docs <https://circuitpython.readthedocs.io/>`_ for extensive API documentation which should
(mostly) work with Blinka.

.. literalinclude:: ../examples/analog_in.py
    :caption: examples/analog_in.py
    :linenos:

.. literalinclude:: ../examples/bbb_digitalio.py
    :caption: examples/bbb_digitalio.py
    :linenos:

.. literalinclude:: ../examples/mcps_busio_i2c.py
    :caption: examples/mcps_busio_i2c.py
    :linenos:

.. literalinclude:: ../examples/pb_digitalio.py
    :caption: examples/pb_digitalio.py
    :linenos:

.. literalinclude:: ../examples/pi_busio_i2c.py
    :caption: examples/pi_busio_i2c.py
    :linenos:

.. literalinclude:: ../examples/pi_busio_spi.py
    :caption: examples/pi_busio_spi.py
    :linenos:

.. literalinclude:: ../examples/pi_digitalio.py
    :caption: examples/pi_digitalio.py
    :linenos:

.. literalinclude:: ../examples/piblinka.py
    :caption: examples/piblinka.py
    :linenos:
